summaryrefslogtreecommitdiff
path: root/mpn/power
diff options
context:
space:
mode:
authorKevin Ryde <user42@zip.com.au>2000-04-16 01:20:01 +0200
committerKevin Ryde <user42@zip.com.au>2000-04-16 01:20:01 +0200
commit92a17b1594132bf5f8c7f9782d85ad5b5bb2eba8 (patch)
treed19a83c2fa5195c6d7c22903719653db1020fd83 /mpn/power
parent119565df1ef96a64307d86f42b1925baecabb85d (diff)
downloadgmp-92a17b1594132bf5f8c7f9782d85ad5b5bb2eba8.tar.gz
Change __mpn to __gmpn.
Diffstat (limited to 'mpn/power')
-rw-r--r--mpn/power/add_n.s14
-rw-r--r--mpn/power/addmul_1.s14
-rw-r--r--mpn/power/lshift.s14
-rw-r--r--mpn/power/mul_1.s14
-rw-r--r--mpn/power/rshift.s14
-rw-r--r--mpn/power/sub_n.s14
-rw-r--r--mpn/power/submul_1.s16
7 files changed, 50 insertions, 50 deletions
diff --git a/mpn/power/lshift.s b/mpn/power/lshift.s
index c11f6d283..b0b27cb48 100644
--- a/mpn/power/lshift.s
+++ b/mpn/power/lshift.s
@@ -1,4 +1,4 @@
-# IBM POWER __mpn_lshift --
+# IBM POWER __gmpn_lshift --
# Copyright (C) 1992, 1994, 1999 Free Software Foundation, Inc.
@@ -27,14 +27,14 @@
# cnt r6
.toc
- .globl __mpn_lshift
- .globl .__mpn_lshift
- .csect __mpn_lshift[DS]
-__mpn_lshift:
- .long .__mpn_lshift, TOC[tc0], 0
+ .globl __gmpn_lshift
+ .globl .__gmpn_lshift
+ .csect __gmpn_lshift[DS]
+__gmpn_lshift:
+ .long .__gmpn_lshift, TOC[tc0], 0
.csect .text[PR]
.align 2
-.__mpn_lshift:
+.__gmpn_lshift:
sli 0,5,2
cax 9,3,0
cax 4,4,0
diff --git a/mpn/power/rshift.s b/mpn/power/rshift.s
index 42cf6b89b..0bd15bae2 100644
--- a/mpn/power/rshift.s
+++ b/mpn/power/rshift.s
@@ -1,4 +1,4 @@
-# IBM POWER __mpn_rshift --
+# IBM POWER __gmpn_rshift --
# Copyright (C) 1992, 1994, 1999 Free Software Foundation, Inc.
@@ -27,14 +27,14 @@
# cnt r6
.toc
- .globl __mpn_rshift
- .globl .__mpn_rshift
- .csect __mpn_rshift[DS]
-__mpn_rshift:
- .long .__mpn_rshift, TOC[tc0], 0
+ .globl __gmpn_rshift
+ .globl .__gmpn_rshift
+ .csect __gmpn_rshift[DS]
+__gmpn_rshift:
+ .long .__gmpn_rshift, TOC[tc0], 0
.csect .text[PR]
.align 2
-.__mpn_rshift:
+.__gmpn_rshift:
sfi 8,6,32
mtctr 5 # put limb count in CTR loop register
l 0,0(4) # read least significant limb
diff --git a/mpn/power/add_n.s b/mpn/power/add_n.s
index c9ec184aa..bad45c6d9 100644
--- a/mpn/power/add_n.s
+++ b/mpn/power/add_n.s
@@ -1,4 +1,4 @@
# IBM POWER __mpn_add_n -- Add two limb vectors of equal, non-zero length.
# Copyright (C) 1992, 1994, 1995, 1996, 1999 Free Software Foundation, Inc.
@@ -27,14 +27,14 @@
# size r6
.toc
- .globl __mpn_add_n
- .globl .__mpn_add_n
- .csect __mpn_add_n[DS]
-__mpn_add_n:
- .long .__mpn_add_n, TOC[tc0], 0
+ .globl __gmpn_add_n
+ .globl .__gmpn_add_n
+ .csect __gmpn_add_n[DS]
+__gmpn_add_n:
+ .long .__gmpn_add_n, TOC[tc0], 0
.csect .text[PR]
.align 2
-.__mpn_add_n:
+.__gmpn_add_n:
andil. 10,6,1 # odd or even number of limbs?
l 8,0(4) # load least significant s1 limb
l 0,0(5) # load least significant s2 limb
@@ -1,4 +1,4 @@
-# IBM POWER __mpn_add_n -- Add two limb vectors of equal, non-zero length.
+# IBM POWER __gmpn_add_n -- Add two limb vectors of equal, non-zero length.
# Copyright (C) 1992, 1994, 1995, 1996, 1999 Free Software Foundation, Inc.
diff --git a/mpn/power/addmul_1.s b/mpn/power/addmul_1.s
index 4a3945882..b7744c0a9 100644
--- a/mpn/power/addmul_1.s
+++ b/mpn/power/addmul_1.s
@@ -1,4 +1,4 @@
# IBM POWER __mpn_addmul_1 -- Multiply a limb vector with a limb and add
# the result to a second limb vector.
# Copyright (C) 1992, 1994, 1999 Free Software Foundation, Inc.
@@ -38,14 +38,14 @@
# we can branch in zero cycles, so that's how we perform the additions.
.toc
- .globl __mpn_addmul_1
- .globl .__mpn_addmul_1
- .csect __mpn_addmul_1[DS]
-__mpn_addmul_1:
- .long .__mpn_addmul_1[PR], TOC[tc0], 0
+ .globl __gmpn_addmul_1
+ .globl .__gmpn_addmul_1
+ .csect __gmpn_addmul_1[DS]
+__gmpn_addmul_1:
+ .long .__gmpn_addmul_1[PR], TOC[tc0], 0
.csect .text[PR]
.align 2
-.__mpn_addmul_1:
+.__gmpn_addmul_1:
cal 3,-4(3)
l 0,0(4)
@@ -1,4 +1,4 @@
-# IBM POWER __mpn_addmul_1 -- Multiply a limb vector with a limb and add
+# IBM POWER __gmpn_addmul_1 -- Multiply a limb vector with a limb and add
# the result to a second limb vector.
# Copyright (C) 1992, 1994, 1999 Free Software Foundation, Inc.
diff --git a/mpn/power/mul_1.s b/mpn/power/mul_1.s
index 097a41278..827ead0f0 100644
--- a/mpn/power/mul_1.s
+++ b/mpn/power/mul_1.s
@@ -1,4 +1,4 @@
# IBM POWER __mpn_mul_1 -- Multiply a limb vector with a limb and store
# the result in a second limb vector.
# Copyright (C) 1992, 1994, 1999 Free Software Foundation, Inc.
@@ -38,14 +38,14 @@
# we can branch in zero cycles, so that's how we perform the additions.
.toc
- .globl __mpn_mul_1
- .globl .__mpn_mul_1
- .csect __mpn_mul_1[DS]
-__mpn_mul_1:
- .long .__mpn_mul_1[PR], TOC[tc0], 0
+ .globl __gmpn_mul_1
+ .globl .__gmpn_mul_1
+ .csect __gmpn_mul_1[DS]
+__gmpn_mul_1:
+ .long .__gmpn_mul_1[PR], TOC[tc0], 0
.csect .text[PR]
.align 2
-.__mpn_mul_1:
+.__gmpn_mul_1:
cal 3,-4(3)
l 0,0(4)
@@ -1,4 +1,4 @@
-# IBM POWER __mpn_mul_1 -- Multiply a limb vector with a limb and store
+# IBM POWER __gmpn_mul_1 -- Multiply a limb vector with a limb and store
# the result in a second limb vector.
# Copyright (C) 1992, 1994, 1999 Free Software Foundation, Inc.
diff --git a/mpn/power/sub_n.s b/mpn/power/sub_n.s
index 3b5c8029f..6dfbb8877 100644
--- a/mpn/power/sub_n.s
+++ b/mpn/power/sub_n.s
@@ -1,4 +1,4 @@
# IBM POWER __mpn_sub_n -- Subtract two limb vectors of equal, non-zero length.
# Copyright (C) 1992, 1994, 1995, 1996, 1999 Free Software Foundation, Inc.
@@ -27,14 +27,14 @@
# size r6
.toc
- .globl __mpn_sub_n
- .globl .__mpn_sub_n
- .csect __mpn_sub_n[DS]
-__mpn_sub_n:
- .long .__mpn_sub_n, TOC[tc0], 0
+ .globl __gmpn_sub_n
+ .globl .__gmpn_sub_n
+ .csect __gmpn_sub_n[DS]
+__gmpn_sub_n:
+ .long .__gmpn_sub_n, TOC[tc0], 0
.csect .text[PR]
.align 2
-.__mpn_sub_n:
+.__gmpn_sub_n:
andil. 10,6,1 # odd or even number of limbs?
l 8,0(4) # load least significant s1 limb
l 0,0(5) # load least significant s2 limb
@@ -1,4 +1,4 @@
-# IBM POWER __mpn_sub_n -- Subtract two limb vectors of equal, non-zero length.
+# IBM POWER __gmpn_sub_n -- Subtract two limb vectors of equal, non-zero length.
# Copyright (C) 1992, 1994, 1995, 1996, 1999 Free Software Foundation, Inc.
diff --git a/mpn/power/submul_1.s b/mpn/power/submul_1.s
index e1f73dc71..26083e4be 100644
--- a/mpn/power/submul_1.s
+++ b/mpn/power/submul_1.s
@@ -1,4 +1,4 @@
# IBM POWER __mpn_submul_1 -- Multiply a limb vector with a limb and subtract
# the result from a second limb vector.
# Copyright (C) 1992, 1994, 1999 Free Software Foundation, Inc.
@@ -38,14 +38,14 @@
# we can branch in zero cycles, so that's how we perform the additions.
.toc
- .globl __mpn_submul_1
- .globl .__mpn_submul_1
- .csect __mpn_submul_1[DS]
-__mpn_submul_1:
- .long .__mpn_submul_1[PR], TOC[tc0], 0
- .csect .__mpn_submul_1[PR]
+ .globl __gmpn_submul_1
+ .globl .__gmpn_submul_1
+ .csect __gmpn_submul_1[DS]
+__gmpn_submul_1:
+ .long .__gmpn_submul_1[PR], TOC[tc0], 0
+ .csect .__gmpn_submul_1[PR]
.align 2
-.__mpn_submul_1:
+.__gmpn_submul_1:
cal 3,-4(3)
l 0,0(4)
@@ -1,4 +1,4 @@
-# IBM POWER __mpn_submul_1 -- Multiply a limb vector with a limb and subtract
+# IBM POWER __gmpn_submul_1 -- Multiply a limb vector with a limb and subtract
# the result from a second limb vector.
# Copyright (C) 1992, 1994, 1999 Free Software Foundation, Inc.